from .ad import fixed_custom_jvp, nondifferentiable_input, nondifferentiable_output
from .bounded_while_loop import bounded_while_loop, HadInplaceUpdate
from .errors import branched_error_if, error_if
from .misc import (
    adjoint_rms_seminorm,
    ContainerMeta,
    fill_forward,
    force_bitcast_convert_type,
    left_broadcast_to,
    linear_rescale,
    rms_norm,
)
from .nextafter import nextafter, nextbefore
from .omega import ω
from .sde_kl_divergence import sde_kl_divergence
from .unvmap import unvmap_all, unvmap_any, unvmap_max
